part of cresce_ui;

class CDurationSlider extends StatefulWidget {
  final Duration min;
  final Duration max;
  final int internalInMinutes;
  final void Function(Duration duration)? onChange;

  const CDurationSlider({
    Key? key,
    required this.min,
    required this.max,
    this.internalInMinutes = 30,
    this.onChange,
  }) : super(key: key);

  @override
  State<CDurationSlider> createState() => _CDurationSliderState();
}

class _CDurationSliderState extends State<CDurationSlider> {
  late int value;

  @override
  void initState() {
    super.initState();
    value = widget.min.inMinutes;
  }

  @override
  Widget build(BuildContext context) {
    return Slider(
      value: value.toDouble(),
      min: widget.min.inMinutes.toDouble(),
      max: widget.max.inMinutes.toDouble(),
      activeColor: const Color(0xFF4CBAAC),
      inactiveColor: const Color(0x204CBAAC),
      thumbColor: const Color(0xFF4CBAAC),
      onChanged: (double value) {
        setState(() {
          this.value = value.round().toInt();
          widget.onChange?.call(getDuration());
        });
      },
      divisions: calculateDivisions(),
      label: format(getDuration()),
    );
  }

  int calculateDivisions() =>
      (widget.max.inMinutes - widget.min.inMinutes) ~/ widget.internalInMinutes;

  String format(Duration duration) {
    var split = duration.toString().split(':');
    return '${split[0]}:${split[1]}';
  }

  Duration getDuration() {
    return Duration(
      hours: value ~/ 60,
      minutes: (((value / 60) - value ~/ 60) * 60).toInt(),
    );
  }
}
